==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/g_structure.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

$core = "group";
$template_file = "structure.tpl.php";

include "inc/header.inc.php";


//append language setup
require_once($languageTextPath . 'node_rules.lang.php');
require_once($languageArrayPath . 'arr_language_name.lang.php');
require_once($languageArrayPath . 'arr_user_priv.lang.php');
require_once($languageArrayPath . 'arr_group_type.lang.php');


$output_council_members = $group->getMembership($group_id, $c_node['user_level_id']['group_council']);
$output_council_chairs = $group->getMembership($group_id, $c_node['user_level_id']['group_chair']);
$output_admin_members = $group->getMembership($group_id, $c_node['user_level_id']['group_administrator']);


//move to template
if (isset($output_group_member_level)) {
	$body->set('group_member_level', $output_group_member_level);
}

if (isset($output_group)) {
	$body->set('group', $output_group);
}

if (isset($output_council_members)) {
	$body->set('council', $output_council_members);
}

if (isset($output_admin_members)) {
	$body->set('group_admins', $output_admin_members);
}

if (isset($output_council_chairs)) {
	$body->set('council_chairs', $output_council_chairs);
}

$template_pageLink = "group";
$template_pageLinkNote = "";
include "inc/footer.inc.php";

?>

==> aroundme_0_4_3.zip: aroundme_0_4_3/www/aroundme_0_4_3/g_structure.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

include "inc/header_group.inc.php";

//append language setup
require_once($languageTextPath . 'node_rules.lang.php');
require_once($languageArrayPath . 'arr_language_name.lang.php');
require_once($languageArrayPath . 'arr_user.lang.php');
require_once($languageArrayPath . 'arr_group.lang.php');


//get count of each memberships role
$group_acs->group_id = $group_id;
$group_roles = $group_acs->getGroupRoles();
$group->member_status_id = $c_node['group']['member_status']['active'];

if (isset($group_roles)) {
    foreach($group_roles as $key => $i):
		$group->role_id = $i['role_id'];
		$group_roles[$key]['total_members'] = $group->getCountMembers();
	endforeach;
}

$lang['txt_node_rules'] = nl2br($lang['txt_node_rules']);


//move to template
if (!empty($group_roles)) {
	$body->set('group_roles', $group_roles);
}

if (!empty($output_group)) {
	$body->set('group', $output_group);
}

include "inc/footer.inc.php";

?>
